@@ -44,8 +44,9 @@
 #include "namespaces.h"
 #include "util.h"
 
-/* 64k is probably a really big default value as XEP 0047 recommends 4k  */
-#define MAX_BLOCK_SIZE (1024 * 64)
+/* 45k gives us 60k after base64 encoding, allowing 4k of header before we hit
+ * ejabberd's default 64k maximum stanza size */
+#define MAX_BLOCK_SIZE (1024 * 45)
 
 static void
 bytestream_iface_init (gpointer g_iface, gpointer iface_data);
@@ -74,6 +75,7 @@ enum
   PROP_STREAM_ID,
   PROP_PEER_JID,
   PROP_STATE,
+  PROP_PROTOCOL,
   LAST_PROPERTY
 };
 
@@ -181,6 +183,9 @@ gabble_bytestream_muc_get_property (GObject *object,
       case PROP_STATE:
         g_value_set_uint (value, priv->state);
         break;
+      case PROP_PROTOCOL:
+        g_value_set_string (value, NS_MUC_BYTESTREAM);
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -278,6 +283,8 @@ gabble_bytestream_muc_class_init (
       "peer-jid");
   g_object_class_override_property (object_class, PROP_STATE,
        "state");
+  g_object_class_override_property (object_class, PROP_PROTOCOL,
+       "protocol");
 
   signals[DATA_RECEIVED] =
     g_signal_new ("data-received",
@@ -580,7 +587,9 @@ gabble_bytestream_muc_receive (GabbleBytestreamMuc *self,
  * Implements gabble_bytestream_iface_accept on GabbleBytestreamIface
  */
 static void
-gabble_bytestream_muc_accept (GabbleBytestreamIface *iface, LmMessage *msg)
+gabble_bytestream_muc_accept (GabbleBytestreamIface *iface,
+                              GabbleBytestreamAugmentSiAcceptReply func,
+                              gpointer user_data)
 {
   /* Don't have to accept a muc bytestream */
 }
@@ -634,17 +643,6 @@ gabble_bytestream_muc_initiate (GabbleBytestreamIface *iface)
   return TRUE;
 }
 
-/*
- * gabble_bytestream_muc_get_protocol
- *
- * Implements gabble_bytestream_iface_get_protocol on GabbleBytestreamIface
- */
-static const gchar *
-gabble_bytestream_muc_get_protocol (GabbleBytestreamIface *iface)
-{
-  return NS_MUC_BYTESTREAM;
-}
-
 static void
 bytestream_iface_init (gpointer g_iface,
                        gpointer iface_data)
@@ -655,5 +653,4 @@ bytestream_iface_init (gpointer g_iface,
   klass->send = gabble_bytestream_muc_send;
   klass->close = gabble_bytestream_muc_close;
   klass->accept = gabble_bytestream_muc_accept;
-  klass->get_protocol = gabble_bytestream_muc_get_protocol;
 }
