@@ -23,10 +23,21 @@
 
 #include <glib.h>
 
+#include "gabble-connection.h"
+
 G_BEGIN_DECLS
 
 void conn_aliasing_iface_init (gpointer g_iface, gpointer iface_data);
 
+gboolean gabble_conn_aliasing_pep_nick_event_handler (GabbleConnection *conn,
+    LmMessage *msg, TpHandle handle);
+
+void gabble_conn_aliasing_nickname_updated (GObject *object,
+    TpHandle handle, gpointer user_data);
+
+GabbleConnectionAliasSource _gabble_connection_get_cached_alias (
+    GabbleConnection *, TpHandle, gchar **);
+
 G_END_DECLS
 
 #endif /* __CONN_ALIASING_H__ */
