@@ -61,12 +61,8 @@ update_own_avatar_sha1 (GabbleConnection *conn,
 
   if (!_gabble_connection_signal_own_presence (conn, &error))
     {
-      if (out_error == NULL)
-        {
-          DEBUG ("failed to signal changed avatar sha1 to the server: %s",
-              error->message);
-          g_error_free (error);
-        }
+      DEBUG ("failed to signal changed avatar sha1 to the server: %s",
+          error->message);
 
       g_propagate_error (out_error, error);
 
@@ -288,8 +284,8 @@ _got_self_avatar_for_get_known_avatar_tokens (GObject *obj,
 
   g_signal_handler_disconnect (obj, context->signal_conn);
 
-  g_hash_table_insert(context->ret, GUINT_TO_POINTER (base->self_handle),
-      g_strdup(sha1));
+  g_hash_table_insert (context->ret, GUINT_TO_POINTER (base->self_handle),
+      g_strdup (sha1));
 
   tp_svc_connection_interface_avatars_return_from_get_known_avatar_tokens (
       context->invocation, context->ret);
@@ -379,6 +375,7 @@ gabble_connection_get_known_avatar_tokens (TpSvcConnectionInterfaceAvatars *ifac
     {
       GetKnownAvatarTokensContext *context = g_slice_new (GetKnownAvatarTokensContext);
 
+      context->conn = self;
       context->invocation = invocation;
       context->ret = ret;
       context->signal_conn = g_signal_connect (self->vcard_manager,
@@ -763,7 +760,7 @@ gabble_connection_set_avatar (TpSvcConnectionInterfaceAvatars *iface,
   if (avatar)
     {
       ctx->avatar = g_string_new_len (avatar->data, avatar->len);
-      base64 = base64_encode (avatar->len, avatar->data);
+      base64 = base64_encode (avatar->len, avatar->data, TRUE);
       value = g_strdup_printf ("%s %s", mime_type, base64);
       g_free (base64);
     }
