@@ -364,6 +364,7 @@ olpc_buddy_info_get_properties (GabbleSvcOLPCBuddyInfo *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -408,6 +409,7 @@ transmit_properties (GabbleConnection *conn,
   LmMessage *msg;
   LmMessageNode *publish;
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -519,7 +521,7 @@ olpc_buddy_info_set_properties (GabbleSvcOLPCBuddyInfo *iface,
               (GDestroyNotify) g_hash_table_destroy);
         }
 
-      gabble_g_hash_table_update (preload, properties,
+      tp_g_hash_table_update (preload, properties,
           (GBoxedCopyFunc) g_strdup,
           (GBoxedCopyFunc) tp_g_value_slice_dup);
 
@@ -534,6 +536,11 @@ olpc_buddy_info_properties_event_handler (GabbleConnection *conn,
 {
   GHashTable *properties;
   LmMessageNode *node;
+  TpBaseConnection *base = (TpBaseConnection*) conn;
+
+  if (handle == base->self_handle)
+    /* Ignore echoed pubsub notifications */
+    return TRUE;
 
   node = lm_message_node_find_child (msg->node, "properties");
   properties = lm_message_node_extract_properties (node, "property");
@@ -862,6 +869,7 @@ olpc_buddy_info_get_activities (GabbleSvcOLPCBuddyInfo *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -965,6 +973,7 @@ olpc_buddy_info_set_activities (GabbleSvcOLPCBuddyInfo *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -1086,6 +1095,11 @@ olpc_buddy_info_activities_event_handler (GabbleConnection *conn,
                                           TpHandle handle)
 {
   GPtrArray *activities;
+  TpBaseConnection *base = (TpBaseConnection*) conn;
+
+  if (handle == base->self_handle)
+    /* Ignore echoed pubsub notifications */
+    return TRUE;
 
   extract_activities (conn, msg, handle);
   activities = get_buddy_activities (conn, handle);
@@ -1233,6 +1247,7 @@ olpc_buddy_info_get_current_activity (GabbleSvcOLPCBuddyInfo *iface,
 
   DEBUG ("called for contact#%u", contact);
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -1307,6 +1322,7 @@ olpc_buddy_info_set_current_activity (GabbleSvcOLPCBuddyInfo *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -1354,6 +1370,11 @@ olpc_buddy_info_current_activity_event_handler (GabbleConnection *conn,
 {
   guint room_handle;
   const gchar *activity;
+  TpBaseConnection *base = (TpBaseConnection*) conn;
+
+  if (handle == base->self_handle)
+    /* Ignore echoed pubsub notifications */
+    return TRUE;
 
   if (extract_current_activity (conn, msg, &activity, &room_handle))
     {
@@ -1568,6 +1589,7 @@ olpc_activity_properties_set_properties (GabbleSvcOLPCActivityProperties *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -1603,7 +1625,7 @@ olpc_activity_properties_set_properties (GabbleSvcOLPCActivityProperties *iface,
 
   properties_copied = g_hash_table_new_full (g_str_hash, g_str_equal, g_free,
       (GDestroyNotify) tp_g_value_slice_free);
-  gabble_g_hash_table_update (properties_copied, properties,
+  tp_g_hash_table_update (properties_copied, properties,
       (GBoxedCopyFunc) g_strdup, (GBoxedCopyFunc) tp_g_value_slice_dup);
 
   info = g_hash_table_lookup (conn->olpc_activities_info,
@@ -1672,6 +1694,7 @@ olpc_activity_properties_get_properties (GabbleSvcOLPCActivityProperties *iface,
 
   DEBUG ("called");
 
+  gabble_connection_ensure_capabilities (conn, PRESENCE_CAP_OLPC_1);
   if (!check_pep (conn, context))
     return;
 
@@ -1832,7 +1855,8 @@ update_activities_properties (GabbleConnection *conn,
 
       old_properties = info->properties;
 
-      new_properties = lm_message_node_extract_properties (properties_node, "property");
+      new_properties = lm_message_node_extract_properties (properties_node,
+          "property");
 
       if (g_hash_table_size (new_properties) == 0)
         {
@@ -1866,6 +1890,12 @@ olpc_activities_properties_event_handler (GabbleConnection *conn,
                                           LmMessage *msg,
                                           TpHandle handle)
 {
+  TpBaseConnection *base = (TpBaseConnection*) conn;
+
+  if (handle == base->self_handle)
+    /* Ignore echoed pubsub notifications */
+    return TRUE;
+
   return update_activities_properties (conn, msg);
 }
 
