@@ -28,11 +28,12 @@ typedef enum
   GABBLE_DEBUG_MUC           = 1 << 7,
   GABBLE_DEBUG_CONNECTION    = 1 << 8,
   GABBLE_DEBUG_IM            = 1 << 9,
-  GABBLE_DEBUG_PERSIST       = 1 << 10,
+  GABBLE_DEBUG_TUBES         = 1 << 10,
   GABBLE_DEBUG_VCARD         = 1 << 11,
   GABBLE_DEBUG_PIPELINE      = 1 << 12,
   GABBLE_DEBUG_JID           = 1 << 13,
   GABBLE_DEBUG_OLPC          = 1 << 14,
+  GABBLE_DEBUG_BYTESTREAM    = 1 << 16,
 } GabbleDebugFlags;
 
 void gabble_debug_set_flags_from_env ();
@@ -53,7 +54,7 @@ G_END_DECLS
 #define NODE_DEBUG(n, s) \
 G_STMT_START { \
   gchar *debug_tmp = lm_message_node_to_string (n); \
-  gabble_debug (DEBUG_FLAG, "%s: " s ":\n%s", G_STRFUNC, debug_tmp); \
+  gabble_debug (DEBUG_FLAG, "%s: %s:\n%s", G_STRFUNC, s, debug_tmp); \
   g_free (debug_tmp); \
 } G_STMT_END
 
@@ -63,11 +64,11 @@ G_STMT_START { \
 
 #ifdef DEBUG_FLAG
 
-#define DEBUG(format, ...) do { } while (0);
+#define DEBUG(format, ...) G_STMT_START { } G_STMT_END
 
 #define DEBUGGING 0
 
-#define NODE_DEBUG(n, s)
+#define NODE_DEBUG(n, s) G_STMT_START { } G_STMT_END
 
 #endif /* DEBUG_FLAG */
 
