@@ -120,8 +120,6 @@ enum
     PROP_STUN_PORT,
     PROP_IGNORE_SSL_ERRORS,
     PROP_ALIAS,
-    PROP_AUTH_MAC,
-    PROP_AUTH_BTID,
 
     LAST_PROPERTY
 };
@@ -164,8 +162,6 @@ struct _GabbleConnectionPrivate
   gchar *resource;
   gint8 priority;
   gchar *alias;
-  gchar *auth_mac;
-  gchar *auth_btid;
 
   /* reference to conference server name */
   const gchar *conference_server;
@@ -327,12 +323,6 @@ gabble_connection_get_property (GObject    *object,
     case PROP_ALIAS:
       g_value_set_string (value, priv->alias);
       break;
-    case PROP_AUTH_MAC:
-      g_value_set_string (value, priv->auth_mac);
-      break;
-    case PROP_AUTH_BTID:
-      g_value_set_string (value, priv->auth_btid);
-      break;
     case PROP_STUN_SERVER:
       g_value_set_string (value, priv->stun_server);
       break;
@@ -411,14 +401,6 @@ gabble_connection_set_property (GObject      *object,
       g_free (priv->alias);
       priv->alias = g_value_dup_string (value);
       break;
-    case PROP_AUTH_MAC:
-      g_free (priv->auth_mac);
-      priv->auth_mac = g_value_dup_string (value);
-      break;
-    case PROP_AUTH_BTID:
-      g_free (priv->auth_btid);
-      priv->auth_btid = g_value_dup_string (value);
-      break;
     case PROP_STUN_SERVER:
       g_free (priv->stun_server);
       priv->stun_server = g_value_dup_string (value);
@@ -536,7 +518,7 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
 
   param_spec = g_param_spec_uint ("port", "Jabber server port",
                                   "The port used when establishing a connection.",
-                                  0, G_MAXUINT16, GABBLE_PARAMS_DEFAULT_PORT,
+                                  0, G_MAXUINT16, 0,
                                   G_PARAM_CONSTRUCT |
                                   G_PARAM_READWRITE |
                                   G_PARAM_STATIC_NAME |
@@ -685,24 +667,6 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                                     G_PARAM_STATIC_BLURB);
   g_object_class_install_property (object_class, PROP_ALIAS, param_spec);
 
-  param_spec = g_param_spec_string ("auth-mac",
-                                    "MAC for authorization",
-                                    "MAC for authorization",
-                                    NULL,
-                                    G_PARAM_READWRITE |
-                                    G_PARAM_STATIC_NAME |
-                                    G_PARAM_STATIC_BLURB);
-  g_object_class_install_property (object_class, PROP_AUTH_MAC, param_spec);
-
-  param_spec = g_param_spec_string ("auth-btid",
-                                    "BTID for authorization",
-                                    "BTID for authorization",
-                                    NULL,
-                                    G_PARAM_READWRITE |
-                                    G_PARAM_STATIC_NAME |
-                                    G_PARAM_STATIC_BLURB);
-  g_object_class_install_property (object_class, PROP_AUTH_BTID, param_spec);
-
   conn_presence_class_init (gabble_connection_class);
 }
 
@@ -801,9 +765,6 @@ gabble_connection_finalize (GObject *object)
 
   g_free (priv->alias);
 
-  g_free (priv->auth_mac);
-  g_free (priv->auth_btid);
-
   conn_presence_finalize (self);
 
   G_OBJECT_CLASS (gabble_connection_parent_class)->finalize (object);
@@ -1160,7 +1121,7 @@ _gabble_connection_connect (TpBaseConnection *base,
   GabbleConnectionPrivate *priv = GABBLE_CONNECTION_GET_PRIVATE (conn);
   char *jid;
 
-  g_assert (priv->port > 0 && priv->port <= G_MAXUINT16);
+  g_assert (priv->port <= G_MAXUINT16);
   g_assert (priv->stream_server != NULL);
   g_assert (priv->username != NULL);
   g_assert (priv->password != NULL);
@@ -1171,20 +1132,35 @@ _gabble_connection_connect (TpBaseConnection *base,
   lm_connection_set_jid (conn->lmconn, jid);
   g_free (jid);
 
-  /* always override server and port if one was forced upon us */
-  if (priv->connect_server != NULL)
+  /* override server and port if either was provided */
+  if (priv->connect_server != NULL || priv->port != 0)
     {
-      lm_connection_set_server (conn->lmconn, priv->connect_server);
-      lm_connection_set_port (conn->lmconn, priv->port);
+      gchar *server;
+
+      if (priv->connect_server != NULL)
+        server = priv->connect_server;
+      else
+        server = priv->stream_server;
+
+      DEBUG ("disabling SRV because \"server\" or \"port\" parameter "
+          "specified, will connect to %s", server);
+
+      lm_connection_set_server (conn->lmconn, server);
+
+      if (priv->port != 0)
+        lm_connection_set_port (conn->lmconn, priv->port);
     }
 #ifndef HAVE_LM_SRV_LOOKUPS
-  /* otherwise set the server & port to the stream server,
-   * if one didn't appear from a SRV lookup */
-  else if (lm_connection_get_server (conn->lmconn) == NULL)
+  /* set the server from the JID if we don't have SRV lookups */
+  else
     {
+      DEBUG ("SRV lookup not supported, will connect to %s",
+          priv->stream_server);
+
       lm_connection_set_server (conn->lmconn, priv->stream_server);
-      lm_connection_set_port (conn->lmconn, priv->port);
     }
+#else
+  DEBUG ("letting SRV lookup decide server and port");
 #endif /* HAVE_LM_SRV_LOOKUPS */
 
   if (priv->https_proxy_server)
@@ -1312,8 +1288,9 @@ _gabble_connection_signal_own_presence (GabbleConnection *self, GError **error)
   LmMessage *message = gabble_presence_as_message (presence, priv->resource);
   LmMessageNode *node = lm_message_get_node (message);
   gboolean ret;
-  gchar *ext_string = NULL;
+  GString *ext_string = NULL;
   GSList *features, *i;
+  GHashTable *bundles;
 
   if (presence->status == GABBLE_PRESENCE_HIDDEN)
     {
@@ -1324,6 +1301,8 @@ _gabble_connection_signal_own_presence (GabbleConnection *self, GError **error)
   /* TODO: why is this not part of presence -> msg? */
   features = capabilities_get_features (presence->caps);
 
+  /* this is used as a set, so any non-NULL value will do */
+  bundles = g_hash_table_new (g_str_hash, g_str_equal);
   for (i = features; NULL != i; i = i->next)
     {
       const Feature *feat = (const Feature *) i->data;
@@ -1332,16 +1311,23 @@ _gabble_connection_signal_own_presence (GabbleConnection *self, GError **error)
         {
           if (NULL != ext_string)
             {
-              gchar *tmp = ext_string;
-              ext_string = g_strdup_printf ("%s %s", ext_string, feat->bundle);
-              g_free (tmp);
+              if (g_hash_table_lookup (bundles, (gchar *) feat->bundle) == NULL)
+                {
+                  /* This bundle wasn't added yet */
+                  g_string_append_printf (ext_string, " %s", feat->bundle);
+                  g_hash_table_insert (bundles, (gchar *) feat->bundle,
+                      (gpointer) feat);
+                }
             }
           else
             {
-              ext_string = g_strdup (feat->bundle);
+              ext_string = g_string_new (feat->bundle);
+              g_hash_table_insert (bundles, (gchar *) feat->bundle,
+                  (gpointer) feat);
             }
         }
     }
+  g_hash_table_destroy (bundles);
 
   node = lm_message_node_add_child (node, "c", NULL);
   lm_message_node_set_attributes (
@@ -1352,13 +1338,15 @@ _gabble_connection_signal_own_presence (GabbleConnection *self, GError **error)
     NULL);
 
   if (NULL != ext_string)
-      lm_message_node_set_attribute (node, "ext", ext_string);
+    {
+      lm_message_node_set_attribute (node, "ext", ext_string->str);
+      g_string_free (ext_string, TRUE);
+    }
 
   ret = _gabble_connection_send (self, message, error);
 
   lm_message_unref (message);
 
-  g_free (ext_string);
   g_slist_free (features);
 
   return ret;
@@ -2743,6 +2731,29 @@ gabble_connection_request_handles (TpSvcConnection *iface,
   tp_base_connection_dbus_request_handles (iface, handle_type, names, context);
 }
 
+void
+gabble_connection_ensure_capabilities (GabbleConnection *self,
+                                       GabblePresenceCapabilities caps)
+{
+  GabbleConnectionPrivate *priv = GABBLE_CONNECTION_GET_PRIVATE (self);
+  GabblePresenceCapabilities old_caps, new_caps;
+
+  old_caps = self->self_presence->caps;
+  new_caps = old_caps;
+  new_caps |= caps;
+
+  if (old_caps ^ new_caps)
+    {
+      /* We changed capabilities */
+      GError *error = NULL;
+
+      gabble_presence_set_capabilities (self->self_presence, priv->resource,
+          new_caps, priv->caps_serial++);
+
+      if (!_gabble_connection_signal_own_presence (self, &error))
+        DEBUG ("error sending presence: %s", error->message);
+    }
+}
 
 /* We reimplement RequestHandles to be able to do async validation on
  * room handles */
