@@ -35,7 +35,6 @@ G_BEGIN_DECLS
 
 /* Default parameters for optional parameters */
 #define GABBLE_PARAMS_DEFAULT_RESOURCE                   "Telepathy"
-#define GABBLE_PARAMS_DEFAULT_PORT                       5222
 #define GABBLE_PARAMS_DEFAULT_HTTPS_PROXY_PORT           443
 #define GABBLE_PARAMS_DEFAULT_STUN_PORT                  3478
 
@@ -183,6 +182,9 @@ const char *_gabble_connection_find_conference_server (GabbleConnection *);
 gboolean _gabble_connection_signal_own_presence (GabbleConnection *,
     GError **);
 
+void gabble_connection_ensure_capabilities (GabbleConnection *conn,
+    GabblePresenceCapabilities caps);
+
 /* extern only for the benefit of the unit tests */
 void _gabble_connection_create_handle_repos (TpBaseConnection *conn,
     TpHandleRepoIface *repos[NUM_TP_HANDLE_TYPES]);
