@@ -69,21 +69,24 @@ struct _GabbleMediaSession {
     gpointer priv;
 };
 
-GType gabble_media_session_get_type(void);
+GType gabble_media_session_get_type (void);
 
 /* TYPE MACROS */
 #define GABBLE_TYPE_MEDIA_SESSION \
-  (gabble_media_session_get_type())
+  (gabble_media_session_get_type ())
 #define GABBLE_MEDIA_SESSION(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), GABBLE_TYPE_MEDIA_SESSION, GabbleMediaSession))
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), GABBLE_TYPE_MEDIA_SESSION, \
+                              GabbleMediaSession))
 #define GABBLE_MEDIA_SESSION_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), GABBLE_TYPE_MEDIA_SESSION, GabbleMediaSessionClass))
+  (G_TYPE_CHECK_CLASS_CAST((klass), GABBLE_TYPE_MEDIA_SESSION, \
+                           GabbleMediaSessionClass))
 #define GABBLE_IS_MEDIA_SESSION(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj), GABBLE_TYPE_MEDIA_SESSION))
 #define GABBLE_IS_MEDIA_SESSION_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE((klass), GABBLE_TYPE_MEDIA_SESSION))
 #define GABBLE_MEDIA_SESSION_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), GABBLE_TYPE_MEDIA_SESSION, GabbleMediaSessionClass))
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), GABBLE_TYPE_MEDIA_SESSION, \
+                              GabbleMediaSessionClass))
 
 /* CONVENIENCE MACROS */
 #define MSG_REPLY_CB_END_SESSION_IF_NOT_SUCCESSFUL(s, m) \
@@ -93,7 +96,8 @@ GType gabble_media_session_get_type(void);
       GMS_DEBUG_ERROR (s, m); \
       NODE_DEBUG (sent_msg->node, "message sent"); \
       NODE_DEBUG (reply_msg->node, "message reply"); \
-      _gabble_media_session_terminate (s, INITIATOR_LOCAL, TP_CHANNEL_GROUP_CHANGE_REASON_ERROR); \
+      _gabble_media_session_terminate (s, INITIATOR_LOCAL, \
+          TP_CHANNEL_GROUP_CHANGE_REASON_ERROR); \
       return LM_HANDLER_RESULT_REMOVE_MESSAGE; \
     } \
   } G_STMT_END
@@ -110,8 +114,10 @@ LmMessage *_gabble_media_session_message_new (GabbleMediaSession *session,
                                               LmMessageNode **session_node);
 
 void _gabble_media_session_accept (GabbleMediaSession *session);
-void _gabble_media_session_remove_streams (GabbleMediaSession *session, GabbleMediaStream **streams, guint len);
-void _gabble_media_session_terminate (GabbleMediaSession *session, JingleInitiator who, TpChannelGroupChangeReason why);
+void _gabble_media_session_remove_streams (GabbleMediaSession *session,
+    GabbleMediaStream **streams, guint len);
+void _gabble_media_session_terminate (GabbleMediaSession *session,
+    JingleInitiator who, TpChannelGroupChangeReason why);
 
 gboolean _gabble_media_session_request_streams (GabbleMediaSession *session,
                                                 const GArray *types,
@@ -119,9 +125,7 @@ gboolean _gabble_media_session_request_streams (GabbleMediaSession *session,
                                                 GError **error);
 
 gboolean _gabble_media_session_request_stream_direction (GabbleMediaSession *,
-                                                         GabbleMediaStream *,
-                                                         TpMediaStreamDirection,
-                                                         GError **);
+    GabbleMediaStream *, TpMediaStreamDirection, GError **);
 
 #ifndef _GMS_DEBUG_LEVEL
 #define _GMS_DEBUG_LEVEL 2
@@ -130,15 +134,20 @@ gboolean _gabble_media_session_request_stream_direction (GabbleMediaSession *,
 #if _GMS_DEBUG_LEVEL
 #ifdef ENABLE_DEBUG
 
-#define GMS_DEBUG_INFO(s, ...)    _gabble_media_session_debug (s, DEBUG_MSG_INFO, __VA_ARGS__)
+#define GMS_DEBUG_INFO(s, ...) \
+  _gabble_media_session_debug (s, DEBUG_MSG_INFO, __VA_ARGS__)
 #if _GMS_DEBUG_LEVEL > 1
-#define GMS_DEBUG_DUMP(s, ...)    _gabble_media_session_debug (s, DEBUG_MSG_DUMP, __VA_ARGS__)
+#define GMS_DEBUG_DUMP(s, ...) \
+  _gabble_media_session_debug (s, DEBUG_MSG_DUMP, __VA_ARGS__)
 #else
 #define GMS_DEBUG_DUMP(s, ...)
 #endif
-#define GMS_DEBUG_WARNING(s, ...) _gabble_media_session_debug (s, DEBUG_MSG_WARNING, __VA_ARGS__)
-#define GMS_DEBUG_ERROR(s, ...)   _gabble_media_session_debug (s, DEBUG_MSG_ERROR, __VA_ARGS__)
-#define GMS_DEBUG_EVENT(s, ...)   _gabble_media_session_debug (s, DEBUG_MSG_EVENT, __VA_ARGS__)
+#define GMS_DEBUG_WARNING(s, ...) \
+  _gabble_media_session_debug (s, DEBUG_MSG_WARNING, __VA_ARGS__)
+#define GMS_DEBUG_ERROR(s, ...) \
+  _gabble_media_session_debug (s, DEBUG_MSG_ERROR, __VA_ARGS__)
+#define GMS_DEBUG_EVENT(s, ...) \
+  _gabble_media_session_debug (s, DEBUG_MSG_EVENT, __VA_ARGS__)
 
 void _gabble_media_session_debug (GabbleMediaSession *session,
                                   DebugMessageType type,
