@@ -353,15 +353,15 @@ properties_disco_cb (GabbleDisco *disco,
   lm_node = lm_message_node_get_child (query_result, "identity");
   if (lm_node)
     {
-      const gchar *type, *category, *name;
+      const gchar *category, *type, *name;
 
-      type = lm_message_node_get_attribute (lm_node, "type");
       category = lm_message_node_get_attribute (lm_node, "category");
+      type = lm_message_node_get_attribute (lm_node, "type");
       name = lm_message_node_get_attribute (lm_node, "name");
 
-      if (NULL != type && 0 == strcmp (type, "text") &&
-          NULL != category && 0 == strcmp (category, "conference") &&
-          NULL != name)
+      if (!tp_strdiff (category, "conference") &&
+          !tp_strdiff (type, "text") &&
+          name != NULL)
         {
           g_value_init (&val, G_TYPE_STRING);
           g_value_set_string (&val, name);
@@ -755,8 +755,9 @@ gabble_muc_channel_set_property (GObject     *object,
       priv->handle = g_value_get_uint (value);
       break;
     case PROP_HANDLE_TYPE:
-      /* this property is writable in the interface, but not actually
-       * meaningfully changable on this channel, so we do nothing */
+    case PROP_CHANNEL_TYPE:
+      /* these properties are writable in the interface, but not actually
+       * meaningfully changeable on this channel, so we do nothing */
       break;
     case PROP_CONNECTION:
       priv->conn = g_value_get_object (value);
@@ -2528,13 +2529,12 @@ request_config_form_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
 
   for (node = form_node->children; node; node = node->next)
     {
-      const gchar *var, *prev_value;
-      LmMessageNode *field_node, *value_node;
+      const gchar *var;
+      LmMessageNode *field_node;
       guint id;
       GType type;
       gboolean invert;
-      gchar buf[16];
-      const gchar *val_str;
+      const gchar *val_str = NULL, *type_str;
       gboolean val_bool;
 
       if (strcmp (node->name, "field") != 0)
@@ -2550,33 +2550,9 @@ request_config_form_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
         continue;
       }
 
-      value_node = lm_message_node_get_child (node, "value");
-      if (value_node == NULL)
-        {
-          DEBUG ("skipping var '%s' because of lacking value attribute",
-                 var);
-          continue;
-        }
-
-      prev_value = lm_message_node_get_value (value_node);
-
-      /* add the corresponding field node to the reply message */
-      field_node = lm_message_node_add_child (submit_node, "field", NULL);
-
-      lm_message_node_set_attribute (field_node, "var", var);
-
-      val_str = lm_message_node_get_attribute (node, "type");
-      if (val_str)
-        {
-          lm_message_node_set_attribute (field_node, "type", val_str);
-        }
-
-      value_node = lm_message_node_add_child (field_node, "value", prev_value);
-
       id = INVALID_ROOM_PROP;
       type = G_TYPE_BOOLEAN;
       invert = FALSE;
-      val_str = NULL;
 
       if (strcmp (var, "anonymous") == 0)
         {
@@ -2663,39 +2639,68 @@ request_config_form_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
       else
         {
           g_warning ("%s: ignoring field '%s'", G_STRFUNC, var);
-          continue;
         }
 
-      DEBUG ("looking up %s... has=%d", room_property_signatures[id].name,
-          tp_properties_context_has (ctx, id));
+      /* add the corresponding field node to the reply message */
+      field_node = lm_message_node_add_child (submit_node, "field", NULL);
+      lm_message_node_set_attribute (field_node, "var", var);
 
-      if (!tp_properties_context_has (ctx, id))
-        continue;
-
-      if (!val_str)
+      type_str = lm_message_node_get_attribute (node, "type");
+      if (type_str)
         {
-          const GValue *provided_value;
-
-          provided_value = tp_properties_context_get (ctx, id);
-
-          switch (type) {
-            case G_TYPE_BOOLEAN:
-              val_bool = g_value_get_boolean (provided_value);
-              sprintf (buf, "%d", (invert) ? !val_bool : val_bool);
-              val_str = buf;
-              break;
-            case G_TYPE_STRING:
-              val_str = g_value_get_string (provided_value);
-              break;
-            default:
-              g_assert_not_reached ();
-          }
+          lm_message_node_set_attribute (field_node, "type", type_str);
         }
 
-      DEBUG ("Setting value %s for %s", val_str, var);
-      lm_message_node_set_value (value_node, val_str);
+      if (id != INVALID_ROOM_PROP && tp_properties_context_has (ctx, id))
+        {
+          /* Known property and we have a value to set */
+          DEBUG ("looking up %s... has=%d", room_property_signatures[id].name,
+              tp_properties_context_has (ctx, id));
 
-      props_left &= ~(1 << id);
+          if (!val_str)
+            {
+              const GValue *provided_value;
+
+              provided_value = tp_properties_context_get (ctx, id);
+
+              switch (type) {
+                case G_TYPE_BOOLEAN:
+                  val_bool = g_value_get_boolean (provided_value);
+                  if (invert)
+                    val_bool = !val_bool;
+                  val_str = val_bool ? "1" : "0";
+                  break;
+                case G_TYPE_STRING:
+                  val_str = g_value_get_string (provided_value);
+                  break;
+                default:
+                  g_assert_not_reached ();
+              }
+            }
+
+          DEBUG ("Setting value %s for %s", val_str, var);
+
+          props_left &= ~(1 << id);
+
+          /* add the corresponding value node(s) to the reply message */
+          lm_message_node_add_child (field_node, "value", val_str);
+        }
+      else
+        {
+          /* Copy all the <value> nodes */
+          LmMessageNode *value_node;
+
+          for (value_node = node->children; value_node != NULL;
+              value_node = value_node->next)
+            {
+              if (tp_strdiff (value_node->name, "value"))
+                /* Not a value, skip it */
+                continue;
+
+              lm_message_node_add_child (field_node, "value",
+                  lm_message_node_get_value (value_node));
+            }
+        }
     }
 
   if (props_left != 0)
