@@ -26,12 +26,20 @@
 
 #include <telepathy-glib/group-mixin.h>
 #include <telepathy-glib/properties-mixin.h>
-#include <telepathy-glib/text-mixin.h>
-#include "handles.h"
+
+#include "gabble-types.h"
+#include "text-mixin.h"
 
 G_BEGIN_DECLS
 
-typedef struct _GabbleMucChannel GabbleMucChannel;
+typedef enum {
+    MUC_STATE_CREATED = 0,
+    MUC_STATE_INITIATED,
+    MUC_STATE_AUTH,
+    MUC_STATE_JOINED,
+    MUC_STATE_ENDED,
+} GabbleMucState;
+
 typedef struct _GabbleMucChannelClass GabbleMucChannelClass;
 
 struct _GabbleMucChannelClass {
@@ -39,7 +47,7 @@ struct _GabbleMucChannelClass {
 
     TpGroupMixinClass group_class;
     TpPropertiesMixinClass properties_class;
-    TpTextMixinClass text_class;
+    GabbleTextMixinClass text_class;
 };
 
 struct _GabbleMucChannel {
@@ -47,34 +55,49 @@ struct _GabbleMucChannel {
 
     TpGroupMixin group;
     TpPropertiesMixin properties;
-    TpTextMixin text;
+    GabbleTextMixin text;
 
     gpointer priv;
 };
 
-GType gabble_muc_channel_get_type(void);
+GType gabble_muc_channel_get_type (void);
 
 /* TYPE MACROS */
 #define GABBLE_TYPE_MUC_CHANNEL \
-  (gabble_muc_channel_get_type())
+  (gabble_muc_channel_get_type ())
 #define GABBLE_MUC_CHANNEL(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), GABBLE_TYPE_MUC_CHANNEL, GabbleMucChannel))
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), GABBLE_TYPE_MUC_CHANNEL, \
+                              GabbleMucChannel))
 #define GABBLE_MUC_CHANNEL_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), GABBLE_TYPE_MUC_CHANNEL, GabbleMucChannelClass))
+  (G_TYPE_CHECK_CLASS_CAST((klass), GABBLE_TYPE_MUC_CHANNEL,\
+                           GabbleMucChannelClass))
 #define GABBLE_IS_MUC_CHANNEL(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj), GABBLE_TYPE_MUC_CHANNEL))
 #define GABBLE_IS_MUC_CHANNEL_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE((klass), GABBLE_TYPE_MUC_CHANNEL))
 #define GABBLE_MUC_CHANNEL_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), GABBLE_TYPE_MUC_CHANNEL, GabbleMucChannelClass))
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), GABBLE_TYPE_MUC_CHANNEL,\
+                              GabbleMucChannelClass))
 
 gboolean _gabble_muc_channel_is_ready (GabbleMucChannel *chan);
-void _gabble_muc_channel_presence_error (GabbleMucChannel *chan, const gchar *jid, LmMessageNode *pres_node);
-void _gabble_muc_channel_member_presence_updated (GabbleMucChannel *chan, TpHandle handle, LmMessage *message, LmMessageNode *x_node);
-gboolean _gabble_muc_channel_receive (GabbleMucChannel *chan, TpChannelTextMessageType msg_type, TpHandleType handle_type, TpHandle sender, time_t timestamp, const gchar *text, LmMessage *msg);
+void _gabble_muc_channel_presence_error (GabbleMucChannel *chan,
+    const gchar *jid, LmMessageNode *pres_node);
+void _gabble_muc_channel_member_presence_updated (GabbleMucChannel *chan,
+    TpHandle handle, LmMessage *message, LmMessageNode *x_node);
+void _gabble_muc_channel_handle_subject (GabbleMucChannel *chan,
+    TpChannelTextMessageType msg_type, TpHandleType handle_type,
+    TpHandle sender, time_t timestamp, const gchar *subject, LmMessage *msg);
+void _gabble_muc_channel_receive (GabbleMucChannel *chan,
+    TpChannelTextMessageType msg_type, TpHandleType handle_type,
+    TpHandle sender, time_t timestamp, const gchar *text, LmMessage *msg);
 
-void _gabble_muc_channel_handle_invited (GabbleMucChannel *chan, TpHandle inviter, const gchar *message);
-void _gabble_muc_channel_state_receive (GabbleMucChannel *chan, guint state, guint from_handle);
+void _gabble_muc_channel_handle_invited (GabbleMucChannel *chan,
+    TpHandle inviter, const gchar *message);
+void _gabble_muc_channel_state_receive (GabbleMucChannel *chan,
+    guint state, guint from_handle);
+
+gboolean gabble_muc_channel_send_presence (GabbleMucChannel *chan,
+    GError **error);
 
 G_END_DECLS
 
