@@ -51,22 +51,6 @@ G_BEGIN_DECLS
     (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                                   GABBLE_TYPE_PRESENCE, GabblePresenceClass))
 
-typedef enum {
-    PRESENCE_CAP_NONE = 0,
-    PRESENCE_CAP_GOOGLE_TRANSPORT_P2P = 1 << 0,
-    PRESENCE_CAP_GOOGLE_VOICE = 1 << 1,
-    PRESENCE_CAP_JINGLE = 1 << 2,
-    PRESENCE_CAP_JINGLE_DESCRIPTION_AUDIO = 1 << 3,
-    PRESENCE_CAP_JINGLE_DESCRIPTION_VIDEO = 1 << 4,
-    PRESENCE_CAP_JINGLE_H263_N800_HACK = 1 << 5,
-    PRESENCE_CAP_CHAT_STATES = 1 << 6,
-    PRESENCE_CAP_SI = 1 << 7,
-    PRESENCE_CAP_BYTESTREAMS = 1 << 8,
-    PRESENCE_CAP_IBB = 1 << 9,
-    PRESENCE_CAP_SI_TUBES = 1 << 10,
-    PRESENCE_CAP_FILE_TRANSFER = 1 << 11,
-} GabblePresenceCapabilities;
-
 struct _GabblePresence {
     GObject parent;
     GabblePresenceCapabilities caps;
