@@ -168,7 +168,7 @@ gabble_tubes_channel_constructor (GType type,
       tp_external_group_mixin_init (obj, (GObject *) self->muc);
       break;
     default:
-      g_assert_not_reached ();
+      g_return_val_if_reached (NULL);
     }
 
   bus = tp_get_bus ();
@@ -230,6 +230,10 @@ gabble_tubes_channel_set_property (GObject *object,
         priv->object_path = g_value_dup_string (value);
         DEBUG ("Setting object_path: %s", priv->object_path);
         break;
+      case PROP_CHANNEL_TYPE:
+      /* this property is writable in the interface, but not actually
+       * meaningfully changeable on this channel, so we do nothing */
+      break;
       case PROP_HANDLE:
         priv->handle = g_value_get_uint (value);
         break;
@@ -417,7 +421,7 @@ create_new_tube (GabbleTubesChannel *self,
           service, parameters, tube_id));
       break;
     default:
-      g_assert_not_reached ();
+      g_return_val_if_reached (NULL);
     }
 
   DEBUG ("create tube %u", tube_id);
@@ -741,7 +745,7 @@ gabble_tubes_channel_presence_updated (GabbleTubesChannel *self,
                     break;
                   default:
                     {
-                      g_assert_not_reached ();
+                      g_return_if_reached ();
                     }
                 }
 
@@ -997,7 +1001,7 @@ publish_tube_in_node (GabbleTubesChannel *self,
         break;
       default:
         {
-          g_assert_not_reached ();
+          g_return_if_reached ();
         }
     }
 
@@ -1832,6 +1836,9 @@ gabble_tubes_channel_accept_d_bus_tube (TpSvcChannelTypeTubes *iface,
   add_yourself_in_dbus_names (self, id);
 
   g_object_get (tube, "dbus-address", &addr, NULL);
+  /* FIXME: This is broken in 1-1 D-Bus tubes because tube_open will be called
+   * only when the bytestream is fully initialised.
+   * So now we return a NULL string. Bug #13891 on fd.o */
   tp_svc_channel_type_tubes_return_from_accept_d_bus_tube (context, addr);
   g_free (addr);
 #else
