@@ -28,6 +28,7 @@
 #include <telepathy-glib/heap.h>
 
 #include "base64.h"
+#include "conn-aliasing.h"
 #include "gabble-connection.h"
 #include "namespaces.h"
 #include "request-pipeline.h"
@@ -36,8 +37,8 @@
 #define DEBUG_FLAG GABBLE_DEBUG_VCARD
 #include "debug.h"
 
-#define DEFAULT_REQUEST_TIMEOUT 20000
-#define VCARD_CACHE_ENTRY_TTL 30
+#define DEFAULT_REQUEST_TIMEOUT 60000
+#define VCARD_CACHE_ENTRY_TTL 60
 
 static const gchar *NO_ALIAS = "none";
 
@@ -529,6 +530,48 @@ gabble_vcard_manager_finalize (GObject *object)
   G_OBJECT_CLASS (gabble_vcard_manager_parent_class)->finalize (object);
 }
 
+static gchar *
+vcard_get_avatar_sha1 (LmMessageNode *vcard)
+{
+  gchar *sha1;
+  const gchar *binval_value;
+  GString *avatar;
+  LmMessageNode *node;
+  LmMessageNode *binval;
+
+  node = lm_message_node_get_child (vcard, "PHOTO");
+
+  if (!node)
+    return g_strdup ("");
+
+  DEBUG ("Our vCard has a PHOTO %p", node);
+  binval = lm_message_node_get_child (node, "BINVAL");
+
+  if (!binval)
+    return g_strdup ("");
+
+  binval_value = lm_message_node_get_value (binval);
+
+  if (!binval_value)
+    return g_strdup ("");
+
+  avatar = base64_decode (binval_value);
+
+  if (avatar)
+    {
+      sha1 = sha1_hex (avatar->str, avatar->len);
+      g_string_free (avatar, TRUE);
+      DEBUG ("Successfully decoded PHOTO.BINVAL, SHA-1 %s", sha1);
+    }
+  else
+    {
+      DEBUG ("Avatar is in garbled Base64, ignoring it!");
+      sha1 = g_strdup ("");
+    }
+
+  return sha1;
+}
+
 /* Called during connection. */
 static void
 initial_request_cb (GabbleVCardManager *self,
@@ -540,60 +583,23 @@ initial_request_cb (GabbleVCardManager *self,
 {
   GabbleVCardManagerPrivate *priv = GABBLE_VCARD_MANAGER_GET_PRIVATE (self);
   gchar *alias = (gchar *)user_data;
-  LmMessageNode *node;
+  gchar *sha1;
 
-  if (!vcard)
+  if (vcard)
     {
-      g_free (alias);
-      return;
-    }
+      /* We now have our own avatar (or lack thereof) so can answer
+       * GetAvatarTokens([self_handle])
+       */
+      priv->have_self_avatar = TRUE;
 
-  /* We now have our own avatar (or lack thereof) so can answer
-   * GetAvatarTokens([self_handle])
-   */
-  priv->have_self_avatar = TRUE;
-
-  /* Do we have an avatar already? If so, the presence cache ought to be
-   * told (anyone else's avatar SHA-1 we'd get from their presence,
-   * but unless we have another XEP-0153 resource connected, we never
-   * see our own presence)
-   */
-  node = lm_message_node_get_child (vcard, "PHOTO");
-  if (node)
-    {
-      DEBUG ("Our vCard has a PHOTO %p", node);
-      LmMessageNode *binval = lm_message_node_get_child (node, "BINVAL");
-
-      if (binval)
-        {
-          const gchar *binval_value;
-
-          binval_value = lm_message_node_get_value (binval);
-
-          if (binval_value)
-            {
-              gchar *sha1;
-              GString *avatar;
-
-              avatar = base64_decode (binval_value);
-
-              if (avatar)
-                {
-                  sha1 = sha1_hex (avatar->str, avatar->len);
-                  DEBUG ("Successfully decoded PHOTO.BINVAL, SHA-1 %s", sha1);
-                  g_signal_emit (self, signals[GOT_SELF_INITIAL_AVATAR], 0,
-                      sha1);
-                  g_free (sha1);
-                }
-              else
-                {
-                  DEBUG ("Avatar is in garbled Base64, ignoring it:\n%s",
-                         lm_message_node_get_value (binval));
-                }
-
-              g_string_free (avatar, TRUE);
-            }
-        }
+      /* Do we have an avatar already? If so, the presence cache ought to be
+       * told (anyone else's avatar SHA-1 we'd get from their presence,
+       * but unless we have another XEP-0153 resource connected, we never
+       * see our own presence)
+       */
+      sha1 = vcard_get_avatar_sha1 (vcard);
+      g_signal_emit (self, signals[GOT_SELF_INITIAL_AVATAR], 0, sha1);
+      g_free (sha1);
     }
 
   g_free (alias);
@@ -832,7 +838,6 @@ observe_vcard (GabbleConnection *conn,
 GError *
 get_error_from_pipeline_reply (LmMessage *reply_msg, GError *error)
 {
-    LmMessageNode *error_node;
     GError *err = NULL;
 
     if (error)
@@ -841,12 +846,7 @@ get_error_from_pipeline_reply (LmMessage *reply_msg, GError *error)
     if (lm_message_get_sub_type (reply_msg) != LM_MESSAGE_SUB_TYPE_ERROR)
         return NULL;
 
-    error_node = lm_message_node_get_child (reply_msg->node, "error");
-    if (error_node)
-      {
-        err = gabble_xmpp_error_to_g_error
-            (gabble_xmpp_error_from_node (error_node));
-      }
+    err = gabble_message_get_xmpp_error (reply_msg);
 
     if (err == NULL)
       {
@@ -875,12 +875,12 @@ replace_reply_cb (GabbleConnection *conn,
 
   DEBUG ("called: %s error", (error) ? "some" : "no");
 
-  g_assert (priv->patched_vcard != NULL);
-
   if (err)
     {
       /* We won't need our patched vcard after all */
-      lm_message_node_unref (priv->patched_vcard);
+      if (priv->patched_vcard != NULL)
+          lm_message_node_unref (priv->patched_vcard);
+
       priv->patched_vcard = NULL;
 
       node = NULL;
@@ -890,8 +890,13 @@ replace_reply_cb (GabbleConnection *conn,
       GabbleVCardCacheEntry *entry = cache_entry_get (manager,
           base->self_handle);
 
+      /* We must have patched vcard by now */
+      g_assert (priv->patched_vcard != NULL);
+
       /* Finally we may put the new vcard in the cache. */
-      lm_message_node_unref (entry->vcard_node);
+      if (entry->vcard_node)
+          lm_message_node_unref (entry->vcard_node);
+
       entry->vcard_node = priv->patched_vcard;
       priv->patched_vcard = NULL;
 
@@ -969,12 +974,21 @@ patch_vcard_foreach (gpointer k, gpointer v, gpointer user_data)
     }
 }
 
-/* Loudmouth hates me. The feelings are mutual. */
+/* Loudmouth hates me. The feelings are mutual.
+ *
+ * Note that this function doesn't copy any attributes other than
+ * xmlns, because LM provides no way to iterate over attributes. Thanks, LM. */
 static LmMessageNode *
 vcard_copy (LmMessageNode *parent, LmMessageNode *src)
 {
     LmMessageNode *child;
-    LmMessageNode *new = lm_message_node_add_child (parent, src->name, src->value);
+    LmMessageNode *new = lm_message_node_add_child (parent, src->name,
+        src->value);
+    const gchar *xmlns;
+
+    xmlns = lm_message_node_get_attribute (src, "xmlns");
+    if (xmlns != NULL)
+      lm_message_node_set_attribute (new, "xmlns", xmlns);
 
     for (child = src->children; child; child = child->next)
         vcard_copy (new, child);
@@ -1065,6 +1079,10 @@ pipeline_reply_cb (GabbleConnection *conn,
        * to the user */
       if (entry->handle == base->self_handle && priv->edits != NULL)
         {
+          /* We won't have a chance to apply those, might as well forget them */
+          g_hash_table_destroy (priv->edits);
+          priv->edits = NULL;
+
           replace_reply_cb (conn, reply_msg, manager, error);
         }
 
